==> random_letter-0.0.2.tar.gz: random_letter-0.0.2/README.md <==
<h1 align="center">RANDOM LETTER</h1>

## What is this project ?

This project is Python package that allows to get a random letter.

## Installation

Install the package using pip:

```sh
python3 -m pip install random-letter
```

## Usage

```python3
import random_letter # import package

letter1 = random_letter.get_random_letter() # get a random lowercase letter
letter2 = random_letter.get_random_letter(True) # get a random uppercase letter

print(letter1, letter2) # print the two letters
```

## You want to contribute ?

If you want to contribute to this project, you are welcome! For this, there are a few steps:

1. Go to the [repository homepage](https://github.com/timotheeMM/random-letter).

2. Create a fork of this project in your GitHub account.

3. Clone this fork on your machine with:

    ```sh
    # make sure that git is installed before doing this
    git clone https://github.com/your-username/random-letter.git
    ```

4. Create a new branch that describes what you want to do by entering:

    ```sh
    git checkout -b my-branch
    ```

5. Make your changes.

6. Add the files you have modified:

    ```sh
    git add .
    ```

7. Make a commit where you say everything you’ve done:

    ```sh
    git commit -m "change... and add..."
    ```

> Please start your commit with a lowercase letter to ensure continuity of commit history

8. Push your changes to GitHub:

    ```sh
    git push -u origin my-branch
    ```

9. Make a pull request by going to the project fork page and clicking on "Contribute > Open pull request". A window will open, and you will be able to explain in more detail all the changes you have made.

10. Validate and then wait for validation... :blush:

:bulb: You can also simply open an issue with the tag "enhancement". Don't forget to give the project a star!

## License

This project is under a [MIT license](https://github.com/timotheeMM/random-letter/blob/main/LICENSE).

==> random_letter-0.0.3.tar.gz: random_letter-0.0.3/README.md <==
<h1 align="center">RANDOM LETTER</h1>

## What is this project ?

This project is Python package that allows to get a random letter.

## Installation

Install the package using pip:

```sh
python3 -m pip install random-letter
```

## Usage

```python3
import random_letter # import package

letter1 = random_letter.get_random_letter() # get a random lowercase letter
letter2 = random_letter.get_random_letter(True) # get a random uppercase letter

print(letter1, letter2) # print the two letters
```

## You want to contribute ?

If you want to contribute to this project, you are welcome! For this, there are a few steps:

1. Go to the [repository homepage](https://github.com/timotheeMM/random-letter).

2. Create a fork of this project in your GitHub account.

3. Clone this fork on your machine with:

    ```sh
    # make sure that git is installed before doing this
    git clone https://github.com/your-username/random-letter.git
    ```

4. Create a new branch that describes what you want to do by entering:

    ```sh
    git checkout -b my-branch
    ```

5. Make your changes.

6. Add the files you have modified:

    ```sh
    git add .
    ```

7. Make a commit where you say everything you’ve done:

    ```sh
    git commit -m "change... and add..."
    ```

> Please start your commit with a lowercase letter to ensure continuity of commit history

8. Push your changes to GitHub:

    ```sh
    git push -u origin my-branch
    ```

9. Make a pull request by going to the project fork page and clicking on "Contribute > Open pull request". A window will open, and you will be able to explain in more detail all the changes you have made.

10. Validate and then wait for validation... 😊

💡 You can also simply open an issue with the tag "enhancement". Don't forget to give the project a star!

## License

This project is under a [MIT license](https://github.com/timotheeMM/random-letter/blob/main/LICENSE).
